@@ -1,9 +1,9 @@
 #' @title Get parameter type-strings.
 #' @description
-#' Returns type strings used in \code{param$type} for certain groups of parameters.
+#' Returns type strings used in `param$type` for certain groups of parameters.
 #' @template arg_include_int
 #' @template arg_include_logical
-#' @return [\code{character}].
+#' @return [`character`].
 #' @name getTypeStrings
 #' @rdname getTypeStrings
 NULL
@@ -17,10 +17,11 @@ getTypeStringsAll = function() {
 #' @export
 #' @rdname getTypeStrings
 getTypeStringsNumeric = function(include.int = TRUE) {
-  if (include.int)
+  if (include.int) {
     ph$type.strings.numeric
-  else
+  } else {
     ph$type.strings.double
+  }
 }
 
 #' @export
@@ -44,10 +45,11 @@ getTypeStringsCharacter = function() {
 #' @export
 #' @rdname getTypeStrings
 getTypeStringsDiscrete = function(include.logical = TRUE) {
-  if (include.logical)
+  if (include.logical) {
     c(ph$type.strings.discrete, ph$type.strings.logical)
-  else
+  } else {
     ph$type.strings.discrete
+  }
 }
 
 #' @export
@@ -55,4 +57,3 @@ getTypeStringsDiscrete = function(include.logical = TRUE) {
 getTypeStringsLogical = function() {
   ph$type.strings.logical
 }
-
