@@ -2,7 +2,7 @@
 #'
 #' @template arg_par_or_set
 #' @template arg_dict
-#' @return [\code{logical(1)}]
+#' @return `logical(1)`
 #' @export
 hasFiniteBoxConstraints = function(par, dict = NULL) {
   UseMethod("hasFiniteBoxConstraints")
@@ -11,15 +11,17 @@ hasFiniteBoxConstraints = function(par, dict = NULL) {
 #' @export
 hasFiniteBoxConstraints.Param = function(par, dict = NULL) {
   bounds = c(getLower(par, dict = dict), getUpper(par, dict = dict))
-  if (length(bounds) == 0)
+  if (length(bounds) == 0) {
     return(TRUE)
+  }
   return(all(is.finite(bounds)))
 }
 
 #' @export
 hasFiniteBoxConstraints.ParamSet = function(par, dict = NULL) {
   bounds = c(getLower(par, dict = dict), getUpper(par, dict = dict))
-  if (length(bounds) == 0)
+  if (length(bounds) == 0) {
     return(TRUE)
+  }
   return(all(is.finite(bounds)))
 }
